<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>MX Repo Manager</source>
        <translation>MX Behandling av pakkearkiv</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Velg APT-pakkearkivet du vil bruke:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX-pakkearkiv</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Velg det raskeste MX-pakkearkivet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>søk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian-pakkearkiv</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Velg det raskeste Debian-pakkearkivet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Frittstående kilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Gjenopprett originale APT-kilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>Om dette programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Avslutt programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>Bruk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="389"/>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <location filename="../mainwindow.cpp" line="696"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Det nye valget vil tre i kraft neste gang kildene oppdateres.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Lists</source>
        <translation>Lister</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Kilder (avkryssede kilder er slått på)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="599"/>
        <location filename="../mainwindow.cpp" line="609"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <location filename="../mainwindow.cpp" line="644"/>
        <location filename="../mainwindow.cpp" line="652"/>
        <location filename="../mainwindow.cpp" line="671"/>
        <location filename="../mainwindow.cpp" line="677"/>
        <location filename="../mainwindow.cpp" line="759"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Could not change the repo.</source>
        <translation>Klarte ikke endre pakkearkivet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Please wait...</source>
        <translation>Vennligst vent …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Program som velger standard APT-pakkearkiv</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="481"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Du har valgt pakkearkivet MX Test. Det anbefales ikke å la det være slått på eller å oppgradere alle pakker fra det.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Det er tryggere å installere enkeltpakker med MX Pakkeinstallering.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Velg APT-pakkearkiv og kildene du vil bruke:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt fant ikke raskeste pakkearkiv.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Could not detect fastest repo.</source>
        <translation>Fant ikke det raskeste pakkearkivet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Klarte ikke finne ut om dette programmet kjører på antiX eller MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>MX version not detected or out of range: </source>
        <translation>Gjenkjente ikke MX-versjon, eller utenfor intervall:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Could not download original APT files.</source>
        <translation>Klarte ikke laste ned originale APT-filer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="677"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Klarte ikke pakke ut nedlastet fil.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Enabling AHS</source>
        <translation>Slår på AHS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Vil du bruke pakkearkivet AHS (Advanced Hardware Stack)?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>De originale APT-kildene er nå gjenopprettet. De selvvalgte kildefilene i /etc/apt/sources.list.d/ opprettholdes.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Feil ved skriving til fil: %1. Undersøk om det er nok ledig plass på disken.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du er innlogget som root. Vennligst logg ut, og logg inn igjen som en vanlig bruker for å bruke dette programmet.</translation>
    </message>
</context>
</TS>
